[all-commits] [llvm/llvm-project] c2ae93: [libc++] Trim down associative container benchmark...
Louis Dionne via All-commits
all-commits at lists.llvm.org
Tue Aug 4 05:57:37 PDT 2026
Branch: refs/heads/main
Home: https://github.com/llvm/llvm-project
Commit: c2ae9308090e26cc6e3e4ab64c06326061c9572c
https://github.com/llvm/llvm-project/commit/c2ae9308090e26cc6e3e4ab64c06326061c9572c
Author: Louis Dionne <ldionne.2 at gmail.com>
Date: 2026-08-04 (Tue, 04 Aug 2026)
Changed paths:
M libcxx/test/benchmarks/containers/associative/associative_container_benchmarks.h
Log Message:
-----------
[libc++] Trim down associative container benchmark sizes (#212252)
Based on local measurements, the associative containers are by far the
slowest benchmarks to run. While there is value in benchmarking small
and large sizes, we can significantly cut down benchmark times by
stripping down to only 2 sizes (from 4).
With this patch, the benchmarks go from 3124s to 1766s across the
associative container benchmarks, which is -43% of their execution time,
and corresponds to ~15% of the entire benchmark suite.
Towards #173032
To unsubscribe from these emails, change your notification settings at https://github.com/llvm/llvm-project/settings/notifications
More information about the All-commits
mailing list